infra

package
v0.8.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2025 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ApplyCDKTF

func ApplyCDKTF(c *config.Config) error

ApplyCDKTF performs the 'apply' of theCDKTF stack

func CheckTerraformVersion

func CheckTerraformVersion() error

CheckTerraformVersion checks if the installed Terraform version matches the required version

func DestroyCDKTF

func DestroyCDKTF(c *config.Config) error

func GetTerraformPath

func GetTerraformPath() (string, error)

GetTerraformPath returns the path to the Terraform binary

func InstallTerraform

func InstallTerraform(version string) error

InstallTerraform installs or updates Terraform to the specified version

Types

This section is empty.

Jump to